from .config import Config, ctypes
from .config import auto_encode

# INT64 __stdcall HCMKB_Bind(int windowsIndex, INT64 hwnd, char* bindConfig);
def HD键鼠_绑定(窗口序号: int, 窗口句柄: int, 绑定属性: str = None) -> int:
    """
    绑定窗口
    
    Args:
        窗口序号: 窗口序号（从1开始）
        窗口句柄: 窗口句柄
        绑定属性: 20个值，1是选中，0未选中，为None表示全部选中
    
    Returns:
        int: 返回值代码（查看HD返回值表）
    """
    hd = Config.get_hd()
    
    HCMKB_Bind = hd.HCMKB_Bind
    HCMKB_Bind.restype = ctypes.c_int64
    HCMKB_Bind.argtypes = [ctypes.c_int32, ctypes.c_int64, ctypes.c_char_p]
    
    绑定属性字节 = auto_encode(绑定属性) if 绑定属性 else None
    
    ret = HCMKB_Bind(
        ctypes.c_int32(窗口序号),
        ctypes.c_int64(窗口句柄),
        绑定属性字节
    )
    return ret

# INT64 __stdcall HCMKB_BindEx(int windowsIndex, INT64 hwnd, char* bindConfig, int bRetMove);
def HD键鼠_绑定Ex(窗口序号: int, 窗口句柄: int, 绑定属性: str = None, 是否刷新: int = 1) -> int:
    """
    绑定窗口（扩展版本）
    
    Args:
        窗口序号: 窗口序号（从1开始）
        窗口句柄: 窗口句柄
        绑定属性: 20个值，1是选中，0未选中，为None表示全部选中
        是否刷新: 是否刷新窗口，有些窗口需要刷新后台键鼠才正常，默认1
    
    Returns:
        int: 返回值代码（查看HD返回值表）
    """
    hd = Config.get_hd()
    
    HCMKB_BindEx = hd.HCMKB_BindEx
    HCMKB_BindEx.restype = ctypes.c_int64
    HCMKB_BindEx.argtypes = [ctypes.c_int32, ctypes.c_int64, ctypes.c_char_p, ctypes.c_int32]
    
    绑定属性字节 = auto_encode(绑定属性) if 绑定属性 else None
    
    ret = HCMKB_BindEx(
        ctypes.c_int32(窗口序号),
        ctypes.c_int64(窗口句柄),
        绑定属性字节,
        ctypes.c_int32(是否刷新)
    )
    return ret

# INT64 __stdcall HCMKB_BindModeEx(int windowsIndex, INT64 hwnd, char* bindConfig, int mode, int bRetMove);
def HD键鼠_模式绑定Ex(窗口序号: int, 窗口句柄: int, 绑定属性: str = None, 模式: int = 0, 是否刷新: int = 1) -> int:
    """
    绑定窗口（扩展接口）
    
    Args:
        窗口序号: 窗口序号
        窗口句柄: 窗口句柄
        绑定属性: 20个值，1是选中，0未选中，为None表示全部选中
        模式: 0通用模式效果最好，1（0模式不行可以试一试这个1），2，3，后续会进一步测试更多的模式
        是否刷新: 是否刷新窗口，有些窗口需要刷新后台键鼠才正常
    
    Returns:
        int: 返回值代码（查看HD返回值表）
    """
    hd = Config.get_hd()
    
    HCMKB_BindModeEx = hd.HCMKB_BindModeEx
    HCMKB_BindModeEx.restype = ctypes.c_int64
    HCMKB_BindModeEx.argtypes = [ctypes.c_int32, ctypes.c_int64, ctypes.c_char_p, ctypes.c_int32, ctypes.c_int32]
    
    绑定属性字节 = auto_encode(绑定属性) if 绑定属性 else None
    
    ret = HCMKB_BindModeEx(
        ctypes.c_int32(窗口序号),
        ctypes.c_int64(窗口句柄),
        绑定属性字节,
        ctypes.c_int32(模式),
        ctypes.c_int32(是否刷新)
    )
    return ret

# INT64 __stdcall HCMKB_SwitchBind(int windowsIndex, INT64 hwnd, char* bindString);
def HD键鼠_切换绑定(窗口序号: int, 窗口句柄: int, 绑定属性: str = None) -> int:
    """
    切换绑定到所属子窗口的句柄上
    
    Args:
        窗口序号: 窗口序号
        窗口句柄: 窗口句柄
        绑定属性: 20个值，1是选中，0未选中，为NULL表示全部选中
    
    Returns:
        int: 返回值代码（查看HD返回值表）
    """
    hd = Config.get_hd()
    
    HCMKB_SwitchBind = hd.HCMKB_SwitchBind
    HCMKB_SwitchBind.restype = ctypes.c_int64
    HCMKB_SwitchBind.argtypes = [ctypes.c_int32, ctypes.c_int64, ctypes.c_char_p]
    
    绑定属性_bytes = auto_encode(绑定属性) if 绑定属性 else None
    
    ret = HCMKB_SwitchBind(
        ctypes.c_int32(窗口序号),
        ctypes.c_int64(窗口句柄),
        绑定属性_bytes
    )
    return ret

# INT64 __stdcall HCMKB_SwitchBindEx(int windowsIndex, INT64 hwnd, char* bindString, int bRetMove);
def HD键鼠_切换绑定Ex(窗口序号: int, 窗口句柄: int, 绑定属性: str = None, 是否刷新: int = 1) -> int:
    """
    切换绑定到所属子窗口的句柄上
    
    Args:
        窗口序号: 窗口序号
        窗口句柄: 窗口句柄
        绑定属性: 20个值，1是选中，0未选中，为NULL表示全部选中
        是否刷新: 是否刷新窗口，有些窗口需要刷新后台键鼠才正常
    
    Returns:
        int: 返回值代码（查看HD返回值表）
    """
    hd = Config.get_hd()
    
    HCMKB_SwitchBindEx = hd.HCMKB_SwitchBindEx
    HCMKB_SwitchBindEx.restype = ctypes.c_int64
    HCMKB_SwitchBindEx.argtypes = [ctypes.c_int32, ctypes.c_int64, ctypes.c_char_p, ctypes.c_int32]
    
    绑定属性_bytes = auto_encode(绑定属性) if 绑定属性 else None
    
    ret = HCMKB_SwitchBindEx(
        ctypes.c_int32(窗口序号),
        ctypes.c_int64(窗口句柄),
        绑定属性_bytes,
        ctypes.c_int32(是否刷新)
    )
    return ret

# INT64 __stdcall HCMKB_SwitchBindModeEx(int windowsIndex, INT64 hwnd, char* bindString, int mode, int bRetMove);
def HD键鼠_切换模式绑定Ex(窗口序号: int, 窗口句柄: int, 绑定属性: str = None, 模式: int = 0, 是否刷新: int = 1) -> int:
    """
    切换绑定窗口（扩展接口）
    
    Args:
        窗口序号: 窗口序号
        窗口句柄: 窗口句柄
        绑定属性: 20个值，1是选中，0未选中，为NULL表示全部选中
        模式: 0通用模式效果最好，1（0模式不行可以试一试这个1），2，后续会进一步测试更多的模式
        是否刷新: 是否刷新窗口，有些窗口需要刷新后台键鼠才正常
    
    Returns:
        int: 返回值代码（查看HD返回值表）
    """
    hd = Config.get_hd()
    
    HCMKB_SwitchBindModeEx = hd.HCMKB_SwitchBindModeEx
    HCMKB_SwitchBindModeEx.restype = ctypes.c_int64
    HCMKB_SwitchBindModeEx.argtypes = [ctypes.c_int32, ctypes.c_int64, ctypes.c_char_p, ctypes.c_int32, ctypes.c_int32]
    
    绑定属性_bytes = auto_encode(绑定属性) if 绑定属性 else None
    
    ret = HCMKB_SwitchBindModeEx(
        ctypes.c_int32(窗口序号),
        ctypes.c_int64(窗口句柄),
        绑定属性_bytes,
        ctypes.c_int32(模式),
        ctypes.c_int32(是否刷新)
    )
    return ret

# INT64 __stdcall HCMKB_PauseBind(int windowsIndex, int bPause, int bRetMove);
def HD键鼠_暂停绑定(窗口序号: int, 是否暂停: bool = True, 是否刷新: int = 1) -> int:
    """
    暂停/恢复后台绑定
    
    Args:
        窗口序号: 窗口序号
        是否暂停: 是否暂停
        是否刷新: 是否刷新窗口，有些窗口需要刷新后台键鼠才正常
    
    Returns:
        int: 返回值代码（查看HD返回值表）
    """
    hd = Config.get_hd()
    
    HCMKB_PauseBind = hd.HCMKB_PauseBind
    HCMKB_PauseBind.restype = ctypes.c_int64
    HCMKB_PauseBind.argtypes = [ctypes.c_int32, ctypes.c_int32, ctypes.c_int32]
    
    ret = HCMKB_PauseBind(
        ctypes.c_int32(窗口序号),
        ctypes.c_int32(是否暂停),
        ctypes.c_int32(是否刷新)
    )
    return ret

# INT64 __stdcall HCMKB_UnBind(int windowsIndex);
def HD键鼠_解绑(窗口序号: int) -> int:
    """
    解绑窗口
    
    Args:
        窗口序号: 窗口序号
    
    Returns:
        int: 返回值代码（查看HD返回值表）
    """
    hd = Config.get_hd()
    
    HCMKB_UnBind = hd.HCMKB_UnBind
    HCMKB_UnBind.restype = ctypes.c_int64
    HCMKB_UnBind.argtypes = [ctypes.c_int32]
    
    ret = HCMKB_UnBind(ctypes.c_int32(窗口序号))
    return ret

# INT64 __stdcall HCMKB_MoveTo(int windowsIndex, int x, int y, BOOL bTrace, int traceType, int windowState);
def HD键鼠_鼠标移动(窗口序号: int, X坐标: int, Y坐标: int, 是否模拟鼠标轨迹: bool = True, 轨迹类型: int = -1, 窗口状态: int = -1) -> int:
    """
    鼠标移动
    
    Args:
        窗口序号: 窗口序号
        X坐标: 窗口客户区坐标x
        Y坐标: 窗口客户区坐标y
        是否模拟鼠标轨迹: 是否模拟鼠标轨迹
        轨迹类型: 轨迹类型，默认-1或1表示随机轨迹，2表示直线轨迹
        窗口状态: 窗口状态，-1/0不设置，其他值为操作前窗口设置
    
    Returns:
        int: 返回值代码（查看HD返回值表）
    """
    hd = Config.get_hd()
    
    HCMKB_MoveTo = hd.HCMKB_MoveTo
    HCMKB_MoveTo.restype = ctypes.c_int64
    HCMKB_MoveTo.argtypes = [ctypes.c_int32, ctypes.c_int32, ctypes.c_int32, ctypes.c_bool, ctypes.c_int32, ctypes.c_int32]
    
    ret = HCMKB_MoveTo(
        ctypes.c_int32(窗口序号),
        ctypes.c_int32(X坐标),
        ctypes.c_int32(Y坐标),
        ctypes.c_bool(是否模拟鼠标轨迹),
        ctypes.c_int32(轨迹类型),
        ctypes.c_int32(窗口状态)
    )
    return ret


# INT64 __stdcall HCMKB_MoveR(int windowsIndex, int x, int y, BOOL bTrace, int traceType, int windowState);
def HD键鼠_鼠标相对移动(窗口序号: int, X坐标: int, Y坐标: int, 是否模拟鼠标轨迹: bool = True, 轨迹类型: int = -1, 窗口状态: int = -1) -> int:
    """
    鼠标移动

    Args:
        窗口序号: 窗口序号
        X坐标: 基于窗口客户区坐标x的当前坐标的水平偏移
        Y坐标: 基于窗口客户区坐标y的当前坐标的垂直偏移
        是否模拟鼠标轨迹: 是否模拟鼠标轨迹
        轨迹类型: 轨迹类型，默认-1或1表示随机轨迹，2表示直线轨迹
        窗口状态: 窗口状态，-1/0不设置，其他值为操作前窗口设置

    Returns:
        int: 返回值代码（查看HD返回值表）
    """
    hd = Config.get_hd()

    HCMKB_MoveR = hd.HCMKB_MoveR
    HCMKB_MoveR.restype = ctypes.c_int64
    HCMKB_MoveR.argtypes = [ctypes.c_int32, ctypes.c_int32, ctypes.c_int32, ctypes.c_bool, ctypes.c_int32,
                             ctypes.c_int32]

    ret = HCMKB_MoveR(
        ctypes.c_int32(窗口序号),
        ctypes.c_int32(X坐标),
        ctypes.c_int32(Y坐标),
        ctypes.c_bool(是否模拟鼠标轨迹),
        ctypes.c_int32(轨迹类型),
        ctypes.c_int32(窗口状态)
    )
    return ret

# INT64 __stdcall HCMKB_KeyUp(int windowsIndex, int virtualKeyCode, int windowState);
def HD键鼠_按键弹起(窗口序号: int, 虚拟键码: int, 窗口状态: int = -1) -> int:
    """
    弹起某个键
    
    Args:
        窗口序号: 窗口序号
        虚拟键码: 虚拟键码
        窗口状态: 窗口状态，-1/0不设置，其他值为操作前窗口设置
    
    Returns:
        int: 返回值代码（查看HD返回值表）
    """
    hd = Config.get_hd()
    
    HCMKB_KeyUp = hd.HCMKB_KeyUp
    HCMKB_KeyUp.restype = ctypes.c_int64
    HCMKB_KeyUp.argtypes = [ctypes.c_int32, ctypes.c_int32, ctypes.c_int32]
    
    ret = HCMKB_KeyUp(
        ctypes.c_int32(窗口序号),
        ctypes.c_int32(虚拟键码),
        ctypes.c_int32(窗口状态)
    )
    return ret

# INT64 __stdcall HCMKB_KeyDown(int windowsIndex, int virtualKeyCode, int windowState);
def HD键鼠_按键按下(窗口序号: int, 虚拟键码: int, 窗口状态: int = -1) -> int:
    """
    按下某个键
    
    Args:
        窗口序号: 窗口序号
        虚拟键码: 虚拟键码
        窗口状态: 窗口状态，-1/0不设置，其他值为操作前窗口设置
    
    Returns:
        int: 返回值代码（查看HD返回值表）
    """
    hd = Config.get_hd()
    
    HCMKB_KeyDown = hd.HCMKB_KeyDown
    HCMKB_KeyDown.restype = ctypes.c_int64
    HCMKB_KeyDown.argtypes = [ctypes.c_int32, ctypes.c_int32, ctypes.c_int32]
    
    ret = HCMKB_KeyDown(
        ctypes.c_int32(窗口序号),
        ctypes.c_int32(虚拟键码),
        ctypes.c_int32(窗口状态)
    )
    return ret

# INT64 __stdcall HCMKB_LeftUp(int windowsIndex, int windowState);
def HD键鼠_左键弹起(窗口序号: int, 窗口状态: int = -1) -> int:
    """
    鼠标左键弹起
    
    Args:
        窗口序号: 窗口序号
        窗口状态: 窗口状态，-1/0不设置，其他值为操作前窗口设置
    
    Returns:
        int: 返回值代码（查看HD返回值表）
    """
    hd = Config.get_hd()
    
    HCMKB_LeftUp = hd.HCMKB_LeftUp
    HCMKB_LeftUp.restype = ctypes.c_int64
    HCMKB_LeftUp.argtypes = [ctypes.c_int32, ctypes.c_int32]
    
    ret = HCMKB_LeftUp(
        ctypes.c_int32(窗口序号),
        ctypes.c_int32(窗口状态)
    )
    return ret

# INT64 __stdcall HCMKB_LeftDown(int windowsIndex, int windowState);
def HD键鼠_左键按下(窗口序号: int, 窗口状态: int = -1) -> int:
    """
    鼠标左键按下
    
    Args:
        窗口序号: 窗口序号
        窗口状态: 窗口状态，-1/0不设置，其他值为操作前窗口设置
    
    Returns:
        int: 返回值代码（查看HD返回值表）
    """
    hd = Config.get_hd()
    
    HCMKB_LeftDown = hd.HCMKB_LeftDown
    HCMKB_LeftDown.restype = ctypes.c_int64
    HCMKB_LeftDown.argtypes = [ctypes.c_int32, ctypes.c_int32]
    
    ret = HCMKB_LeftDown(
        ctypes.c_int32(窗口序号),
        ctypes.c_int32(窗口状态)
    )
    return ret

# INT64 __stdcall HCMKB_LeftClick(int windowsIndex, int delayMs, int windowState);
def HD键鼠_左键点击(窗口序号: int, 延时毫秒: int = 50, 窗口状态: int = -1) -> int:
    """
    鼠标左键点击
    
    Args:
        窗口序号: 窗口序号
        延时毫秒: 延时毫秒（默认50毫秒）
        窗口状态: 窗口状态，-1/0不设置，其他值为操作前窗口设置
    
    Returns:
        int: 返回值代码（查看HD返回值表）
    """
    hd = Config.get_hd()
    
    HCMKB_LeftClick = hd.HCMKB_LeftClick
    HCMKB_LeftClick.restype = ctypes.c_int64
    HCMKB_LeftClick.argtypes = [ctypes.c_int32, ctypes.c_int32, ctypes.c_int32]
    
    ret = HCMKB_LeftClick(
        ctypes.c_int32(窗口序号),
        ctypes.c_int32(延时毫秒),
        ctypes.c_int32(窗口状态)
    )
    return ret

# INT64 __stdcall HCMKB_LeftDoubleClick(int windowsIndex, int delayMs, int windowState);
def HD键鼠_左键双击(窗口序号: int, 延时毫秒: int = 50, 窗口状态: int = -1) -> int:
    """
    鼠标左键双击
    
    Args:
        窗口序号: 窗口序号
        延时毫秒: 延时毫秒（默认50毫秒）
        窗口状态: 窗口状态，-1/0不设置，其他值为操作前窗口设置
    
    Returns:
        int: 返回值代码（查看HD返回值表）
    """
    hd = Config.get_hd()
    
    HCMKB_LeftDoubleClick = hd.HCMKB_LeftDoubleClick
    HCMKB_LeftDoubleClick.restype = ctypes.c_int64
    HCMKB_LeftDoubleClick.argtypes = [ctypes.c_int32, ctypes.c_int32, ctypes.c_int32]
    
    ret = HCMKB_LeftDoubleClick(
        ctypes.c_int32(窗口序号),
        ctypes.c_int32(延时毫秒),
        ctypes.c_int32(窗口状态)
    )
    return ret

# INT64 __stdcall HCMKB_MiddleUp(int windowsIndex, int windowState);
def HD键鼠_中键弹起(窗口序号: int, 窗口状态: int = -1) -> int:
    """
    鼠标中键弹起
    
    Args:
        窗口序号: 窗口序号
        窗口状态: 窗口状态，-1/0不设置，其他值为操作前窗口设置
        
    Returns:
        int: 返回值代码（查看HD返回值表）
    """
    hd = Config.get_hd()
    
    func = hd.HCMKB_MiddleUp
    func.restype = ctypes.c_int64
    func.argtypes = [ctypes.c_int, ctypes.c_int]
    
    return func(窗口序号, 窗口状态)

# INT64 __stdcall HCMKB_MiddleDown(int windowsIndex, int windowState);
def HD键鼠_中键按下(窗口序号: int, 窗口状态: int = -1) -> int:
    """
    鼠标中键按下
    
    Args:
        窗口序号: 窗口序号
        窗口状态: 窗口状态，-1/0不设置，其他值为操作前窗口设置
        
    Returns:
        int: 返回值代码（查看HD返回值表）
    """
    hd = Config.get_hd()
    
    func = hd.HCMKB_MiddleDown
    func.restype = ctypes.c_int64
    func.argtypes = [ctypes.c_int, ctypes.c_int]
    
    return func(窗口序号, 窗口状态)

# INT64 __stdcall HCMKB_MiddleClick(int windowsIndex, int delayMs, int windowState);
def HD键鼠_中键点击(窗口序号: int, 延时毫秒: int = 50, 窗口状态: int = -1) -> int:
    """
    鼠标中键点击
    
    Args:
        窗口序号: 窗口序号
        延时毫秒: 延时毫秒（默认50毫秒）
        窗口状态: 窗口状态，-1/0不设置，其他值为操作前窗口设置
        
    Returns:
        int: 返回值代码（查看HD返回值表）
    """
    hd = Config.get_hd()
    
    func = hd.HCMKB_MiddleClick
    func.restype = ctypes.c_int64
    func.argtypes = [ctypes.c_int, ctypes.c_int, ctypes.c_int]
    
    return func(窗口序号, 延时毫秒, 窗口状态)

# INT64 __stdcall HCMKB_MiddleDoubleClick(int windowsIndex, int delayMs, int windowState);
def HD键鼠_中键双击(窗口序号: int, 延时毫秒: int = 50, 窗口状态: int = -1) -> int:
    """
    鼠标中键双击
    
    Args:
        窗口序号: 窗口序号
        延时毫秒: 延时毫秒（默认50毫秒）
        窗口状态: 窗口状态，-1/0不设置，其他值为操作前窗口设置
        
    Returns:
        int: 返回值代码（查看HD返回值表）
    """
    hd = Config.get_hd()
    
    func = hd.HCMKB_MiddleDoubleClick
    func.restype = ctypes.c_int64
    func.argtypes = [ctypes.c_int, ctypes.c_int, ctypes.c_int]
    
    return func(窗口序号, 延时毫秒, 窗口状态)

# INT64 __stdcall HCMKB_RightUp(int windowsIndex, int windowState);
def HD键鼠_右键弹起(窗口序号: int, 窗口状态: int = -1) -> int:
    """
    鼠标右键弹起
    
    Args:
        窗口序号: 窗口序号
        窗口状态: 窗口状态，-1/0不设置，其他值为操作前窗口设置
        
    Returns:
        int: 返回值代码（查看HD返回值表）
    """
    hd = Config.get_hd()
    
    func = hd.HCMKB_RightUp
    func.restype = ctypes.c_int64
    func.argtypes = [ctypes.c_int, ctypes.c_int]
    
    return func(窗口序号, 窗口状态)

# INT64 __stdcall HCMKB_RightDown(int windowsIndex, int windowState);
def HD键鼠_右键按下(窗口序号: int, 窗口状态: int = -1) -> int:
    """
    鼠标右键按下
    
    Args:
        窗口序号: 窗口序号
        窗口状态: 窗口状态，-1/0不设置，其他值为操作前窗口设置
        
    Returns:
        int: 返回值代码（查看HD返回值表）
    """
    hd = Config.get_hd()
    
    func = hd.HCMKB_RightDown
    func.restype = ctypes.c_int64
    func.argtypes = [ctypes.c_int, ctypes.c_int]
    
    return func(窗口序号, 窗口状态)

# INT64 __stdcall HCMKB_RightClick(int windowsIndex, int delayMs, int windowState);
def HD键鼠_右键点击(窗口序号: int, 延时毫秒: int = 50, 窗口状态: int = -1) -> int:
    """
    鼠标右键点击
    
    Args:
        窗口序号: 窗口序号
        延时毫秒: 延时毫秒（默认50毫秒）
        窗口状态: 窗口状态，-1/0不设置，其他值为操作前窗口设置
        
    Returns:
        int: 返回值代码（查看HD返回值表）
    """
    hd = Config.get_hd()
    
    func = hd.HCMKB_RightClick
    func.restype = ctypes.c_int64
    func.argtypes = [ctypes.c_int, ctypes.c_int, ctypes.c_int]
    
    return func(窗口序号, 延时毫秒, 窗口状态)

# INT64 __stdcall HCMKB_RightDoubleClick(int windowsIndex, int delayMs, int windowState);
def HD键鼠_右键双击(窗口序号: int, 延时毫秒: int = 50, 窗口状态: int = -1) -> int:
    """
    鼠标右键双击
    
    Args:
        窗口序号: 窗口序号
        延时毫秒: 延时毫秒（默认50毫秒）
        窗口状态: 窗口状态，-1/0不设置，其他值为操作前窗口设置
        
    Returns:
        int: 返回值代码（查看HD返回值表）
    """
    hd = Config.get_hd()
    
    func = hd.HCMKB_RightDoubleClick
    func.restype = ctypes.c_int64
    func.argtypes = [ctypes.c_int, ctypes.c_int, ctypes.c_int]
    
    return func(窗口序号, 延时毫秒, 窗口状态)

# INT64 __stdcall HCMKB_WheelUp(int windowsIndex, int windowState);
def HD键鼠_滚轮向上(窗口序号: int, 窗口状态: int = -1) -> int:
    """
    鼠标滚轮向上滚动
    
    Args:
        窗口序号: 窗口序号
        窗口状态: 窗口状态，-1/0不设置，其他值为操作前窗口设置
        
    Returns:
        int: 返回值代码（查看HD返回值表）
    """
    hd = Config.get_hd()
    
    func = hd.HCMKB_WheelUp
    func.restype = ctypes.c_int64
    func.argtypes = [ctypes.c_int, ctypes.c_int]
    
    return func(窗口序号, 窗口状态)

# INT64 __stdcall HCMKB_WheelDown(int windowsIndex, int windowState);
def HD键鼠_滚轮向下(窗口序号: int, 窗口状态: int = -1) -> int:
    """
    鼠标滚轮向下滚动
    
    Args:
        窗口序号: 窗口序号
        窗口状态: 窗口状态，-1/0不设置，其他值为操作前窗口设置
        
    Returns:
        int: 返回值代码（查看HD返回值表）
    """
    hd = Config.get_hd()
    
    func = hd.HCMKB_WheelDown
    func.restype = ctypes.c_int64
    func.argtypes = [ctypes.c_int, ctypes.c_int]
    
    return func(窗口序号, 窗口状态)

# INT64 __stdcall HCMKB_KeyPress(int windowsIndex, int virtualKeyCode, int delayMs, int windowState);
def HD键鼠_按键(窗口序号: int, 虚拟键码: int, 延时毫秒: int = 20, 窗口状态: int = -1) -> int:
    """
    按下某个键
    
    Args:
        窗口序号: 窗口序号
        虚拟键码: 虚拟键码
        延时毫秒: 延时毫秒（默认20毫秒）
        窗口状态: 窗口状态，-1/0不设置，其他值为操作前窗口设置
        
    Returns:
        int: 返回值代码（查看HD返回值表）
    """
    hd = Config.get_hd()
    
    func = hd.HCMKB_KeyPress
    func.restype = ctypes.c_int64
    func.argtypes = [ctypes.c_int, ctypes.c_int, ctypes.c_int, ctypes.c_int]
    
    return func(窗口序号, 虚拟键码, 延时毫秒, 窗口状态)

# INT64 __stdcall HCMKB_KeyPressA(int windowsIndex, char* text, int delayMs, int windowState);
def HD键鼠_连续按键A(窗口序号: int, 文本: str, 延时毫秒: int = 20, 窗口状态: int = -1) -> int:
    """
    连续按键输入字符串（连续单个按键）
    
    Args:
        窗口序号: 窗口序号
        文本: 要输入的字符串（ASCII字符）
        延时毫秒: 延时毫秒（默认20毫秒）
        窗口状态: 窗口状态，-1/0不设置，其他值为操作前窗口设置
        
    Returns:
        int: 返回值代码（查看HD返回值表）
    """
    hd = Config.get_hd()
    
    func = hd.HCMKB_KeyPressA
    func.restype = ctypes.c_int64
    func.argtypes = [ctypes.c_int, ctypes.c_char_p, ctypes.c_int, ctypes.c_int]
    
    return func(窗口序号, auto_encode(文本), 延时毫秒, 窗口状态)

# INT64 __stdcall HCMKB_KeyPressW(int windowsIndex, wchar_t* text, int delayMs, int windowState);
def HD键鼠_连续按键W(窗口序号: int, 文本: str, 延时毫秒: int = 20, 窗口状态: int = -1) -> int:
    """
    连续按键输入字符串（连续单个按键）
    
    Args:
        窗口序号: 窗口序号
        文本: 要输入的字符串（Unicode字符）
        延时毫秒: 延时毫秒（默认20毫秒）
        窗口状态: 窗口状态，-1/0不设置，其他值为操作前窗口设置
        
    Returns:
        int: 返回值代码（查看HD返回值表）
    """
    hd = Config.get_hd()
    
    func = hd.HCMKB_KeyPressW
    func.restype = ctypes.c_int64
    func.argtypes = [ctypes.c_int, ctypes.c_wchar_p, ctypes.c_int, ctypes.c_int]
    
    return func(窗口序号, 文本, 延时毫秒, 窗口状态)

def HD键鼠_发送文本A(窗口序号: int, 文本A: str, 延时毫秒: int = 20, 窗口状态: int = -1) -> int:
    # INT64 __stdcall HCMKB_SendStringA(INT32 窗口序号, LPCSTR 文本A, INT32 延时毫秒, INT32 窗口状态);
    """
    发送Ascii字符串 (不同于连续单个按键)
    
    Args:
        窗口序号: 窗口序号
        文本A: 文本(Ascii)
        延时毫秒: 延时毫秒（默认20毫秒）
        窗口状态: 窗口状态，-1/0不设置，其他值为操作前窗口设置
        
    Returns:
        int: 操作结果
    """
    hd = Config.get_hd()
    func = hd.HCMKB_SendStringA
    func.restype = ctypes.c_int64
    func.argtypes = [ctypes.c_int32, ctypes.c_char_p, ctypes.c_int32, ctypes.c_int32]
    
    return func(窗口序号, auto_encode(文本A), 延时毫秒, 窗口状态)

def HD键鼠_发送文本W(窗口序号: int, 文本W: str, 延时毫秒: int = 20, 窗口状态: int = -1) -> int:
    # INT64 __stdcall HCMKB_SendStringW(INT32 窗口序号, LPCWSTR 文本W, INT32 延时毫秒, INT32 窗口状态);
    """
    发送Unicode字符串 (不同于连续单个按键)
    
    Args:
        窗口序号: 窗口序号
        文本W: 文本(Unicode)
        延时毫秒: 延时毫秒（默认20毫秒）
        窗口状态: 窗口状态，-1/0不设置，其他值为操作前窗口设置
        
    Returns:
        int: 操作结果
    """
    hd = Config.get_hd()
    func = hd.HCMKB_SendStringW
    func.restype = ctypes.c_int64
    func.argtypes = [ctypes.c_int32, ctypes.c_wchar_p, ctypes.c_int32, ctypes.c_int32]
    
    return func(窗口序号, 文本W, 延时毫秒, 窗口状态)

def HD键鼠_发送文本1(窗口序号: int, 文本A: str, 延时毫秒: int = 20, 窗口状态: int = -1) -> int:
    # INT64 __stdcall HCMKB_SendString(INT32 窗口序号, LPCSTR 文本A, INT32 延时毫秒, INT32 窗口状态);
    """
    发送Ascii字符串
    
    Args:
        窗口序号: 窗口序号
        文本A: 文本(Ascii)
        延时毫秒: 延时毫秒（默认20毫秒）
        窗口状态: 窗口状态，-1/0不设置，其他值为操作前窗口设置
        
    Returns:
        int: 操作结果
    """
    hd = Config.get_hd()
    func = hd.HCMKB_SendString
    func.restype = ctypes.c_int64
    func.argtypes = [ctypes.c_int32, ctypes.c_char_p, ctypes.c_int32, ctypes.c_int32]
    
    return func(窗口序号, auto_encode(文本A), 延时毫秒, 窗口状态)

def HD键鼠_发送文本2(窗口序号: int, 文本A: str, 延时毫秒: int = 20, 窗口状态: int = -1) -> int:
    # INT64 __stdcall HCMKB_SendString2(INT32 窗口序号, LPCSTR 文本A, INT32 延时毫秒, INT32 窗口状态);
    """
    发送Ascii字符串
    
    Args:
        窗口序号: 窗口序号
        文本A: 文本(Ascii)
        延时毫秒: 延时毫秒（默认20毫秒）
        窗口状态: 窗口状态，-1/0不设置，其他值为操作前窗口设置
        
    Returns:
        int: 操作结果
    """
    hd = Config.get_hd()
    func = hd.HCMKB_SendString2
    func.restype = ctypes.c_int64
    func.argtypes = [ctypes.c_int32, ctypes.c_char_p, ctypes.c_int32, ctypes.c_int32]
    
    return func(窗口序号, auto_encode(文本A), 延时毫秒, 窗口状态)

def HD键鼠_剪切板发送文本(窗口序号: int, 发送字节缓冲区: bytes, 发送字节大小: int, 文本类型: int, mis: int = 20, 窗口状态: int = -1) -> int:
    # INT64 __stdcall HCMKB_SendPaste(INT32 窗口序号, LPVOID 发送字节缓冲区, INT32 发送字节大小, INT32 文本类型, INT32 mis, INT32 窗口状态);
    """
    发送剪切板字符串内容到窗口
    
    Args:
        窗口序号: 窗口序号
        发送字节缓冲区: 发送字节缓冲区 (bytes) - 字节数组，如：b'\x01\x02\x03' 或 bytes([1, 2, 3])
        发送字节大小: 发送字节缓冲区的字节大小
        文本类型: Ascii(1)  Unicode(2)
        mis: 延时毫秒
        窗口状态: 窗口状态，-1/0不设置，其他值为操作前窗口设置
        
    Returns:
        int: 操作结果
    """
    hd = Config.get_hd()
    func = hd.HCMKB_SendPaste
    func.restype = ctypes.c_int64
    func.argtypes = [ctypes.c_int32, ctypes.c_void_p, ctypes.c_int32, ctypes.c_int32, ctypes.c_int32, ctypes.c_int32]
    
    buffer = ctypes.c_char_p(发送字节缓冲区)
    
    return func(窗口序号, buffer, 发送字节大小, 文本类型, mis, 窗口状态)

def HD键鼠_剪切板发送文本Ex(窗口序号: int, 发送字节缓冲区: bytes, 发送字节大小: int, 文本类型: int, bSend: int = 0, mis: int = 20, 窗口状态: int = -1) -> int:
    # INT64 __stdcall HCMKB_SendPasteEx(INT32 窗口序号, LPVOID 发送字节缓冲区, INT32 发送字节大小, INT32 文本类型, INT32 bSend, INT32 mis, INT32 窗口状态);
    """
    发送剪切板字符串内容到窗口
    
    Args:
        窗口序号: 窗口序号
        发送字节缓冲区: 发送字节缓冲区 (bytes) - 字节数组，如：b'\x01\x02\x03' 或 bytes([1, 2, 3])
        发送字节大小: 发送字节缓冲区的字节大小
        文本类型: Ascii(1)  Unicode(2)
        bSend: 是否消息发送的方式传递文本,如果为假表示粘贴到文本框
        mis: 延时毫秒
        窗口状态: 窗口状态，-1/0不设置，其他值为操作前窗口设置
        
    Returns:
        int: 操作结果
    """
    hd = Config.get_hd()
    func = hd.HCMKB_SendPasteEx
    func.restype = ctypes.c_int64
    func.argtypes = [ctypes.c_int32, ctypes.c_void_p, ctypes.c_int32, ctypes.c_int32, ctypes.c_int32, ctypes.c_int32, ctypes.c_int32]
    
    buffer = ctypes.c_char_p(发送字节缓冲区)
    
    return func(窗口序号, buffer, 发送字节大小, 文本类型, bSend, mis, 窗口状态)

def HD键鼠_剪切板发送随机文本(窗口序号: int, bSend: int = 0, mis: int = 20, 窗口状态: int = -1) -> int:
    # INT64 __stdcall HCMKB_SendRoundNamePaste(INT32 窗口序号, INT32 bSend, INT32 mis, INT32 窗口状态);
    """
    发送随机名字,从2个文本(hf.txt 和 he.txt )中各获取一个字
    
    Args:
        窗口序号: 窗口序号
        bSend: 是否消息发送的方式传递文本,如果为假表示粘贴到文本框
        mis: 延时毫秒
        窗口状态: 窗口状态，-1/0不设置，其他值为操作前窗口设置
        
    Returns:
        int: 操作结果
    """
    hd = Config.get_hd()
    func = hd.HCMKB_SendRoundNamePaste
    func.restype = ctypes.c_int64
    func.argtypes = [ctypes.c_int32, ctypes.c_int32, ctypes.c_int32, ctypes.c_int32]
    
    return func(窗口序号, bSend, mis, 窗口状态)

def HD键鼠_设置剪切板文本(发送字节缓冲区: bytes, 发送字节大小: int, 文本类型: int) -> int:
    # INT64 __stdcall HCMKB_SetClipboard(LPVOID 发送字节缓冲区, INT32 发送字节大小, INT32 文本类型);
    """
    设置剪切板字符串
    
    Args:
        发送字节缓冲区: 发送字节缓冲区 (bytes) - 字节数组，如：b'\x01\x02\x03' 或 bytes([1, 2, 3])
        发送字节大小: 发送字节缓冲区的字节大小
        文本类型: Ascii(1)  Unicode(2)  Utf-8(3)
        
    Returns:
        int: 操作结果
    """
    hd = Config.get_hd()
    func = hd.HCMKB_SetClipboard
    func.restype = ctypes.c_int64
    func.argtypes = [ctypes.c_void_p, ctypes.c_int32, ctypes.c_int32]
    
    buffer = ctypes.c_char_p(发送字节缓冲区)
    
    return func(buffer, 发送字节大小, 文本类型)

def HD键鼠_获取剪切板字符串(文本类型: int) -> int:
    # INT64 __stdcall HCMKB_GetClipboard(INT32 文本类型);
    """
    获取剪切板字符串
    
    Args:
        文本类型: Ascii(1)  Unicode(2)
        
    Returns:
        int: 剪切板字符串
    """
    hd = Config.get_hd()
    func = hd.HCMKB_GetClipboard
    func.restype = ctypes.c_int64
    func.argtypes = [ctypes.c_int32]
    
    return func(文本类型)

def HD键鼠_句柄发送文本(hwnd: int, 文本A: str, 延时毫秒: int = 20, 窗口状态: int = -1) -> int:
    # INT64 __stdcall HCMKB_SendStringF(INT64 hwnd, LPCSTR 文本A, INT32 延时毫秒, INT32 窗口状态);
    """
    发送Ascii字符串,部分游戏需要激活窗口！（可以不用通讯调用）
    
    Args:
        hwnd: hwnd窗口句柄
        文本A: 文本(Ascii)
        延时毫秒: 延时毫秒（默认20毫秒）
        窗口状态: 窗口状态，-1/0不设置，其他值为操作前窗口设置
        
    Returns:
        int: 操作结果
    """
    hd = Config.get_hd()
    func = hd.HCMKB_SendStringF
    func.restype = ctypes.c_int64
    func.argtypes = [ctypes.c_int64, ctypes.c_char_p, ctypes.c_int32, ctypes.c_int32]
    
    return func(hwnd, auto_encode(文本A), 延时毫秒, 窗口状态)

def HD键鼠_句柄发送按键按下(窗口序号: int, hwnd: int, 虚拟键码: int, 窗口状态: int = 0) -> int:
    # INT64 __stdcall HCMKB_SendKeyDownF(INT32 窗口序号, INT32 hwnd, INT32 虚拟键码, INT32 窗口状态);
    """
    按下发送键码到指定窗口（可以不用通讯调用）
    
    Args:
        窗口序号: 窗口序号 (不需要通讯也可以调用,指定一个大于0的序号就行或者任意一个)
        hwnd: hwnd窗口句柄(指定子窗口的窗口句柄,可以指定非绑定窗口的子窗口)
        虚拟键码: 虚拟键码
        窗口状态: 窗口状态，-1/0不设置，其他值为操作前窗口设置(值)参考: HCWIN_SetWindowState的参数值
        
    Returns:
        int: 操作结果
    """
    hd = Config.get_hd()
    func = hd.HCMKB_SendKeyDownF
    func.restype = ctypes.c_int64
    func.argtypes = [ctypes.c_int32, ctypes.c_int32, ctypes.c_int32, ctypes.c_int32]
    
    return func(窗口序号, hwnd, 虚拟键码, 窗口状态)

def HD键鼠_句柄发送按键弹起(窗口序号: int, hwnd: int, 虚拟键码: int, 窗口状态: int = 0) -> int:
    # INT64 __stdcall HCMKB_SendKeyUpF(INT32 窗口序号, INT32 hwnd, INT32 虚拟键码, INT32 窗口状态);
    """
    弹起发送键码到指定窗口（可以不用通讯调用）
    
    Args:
        窗口序号: 窗口序号 (不需要通讯也可以调用,指定一个大于0的序号就行或者任意一个)
        hwnd: hwnd窗口句柄(指定子窗口的窗口句柄,可以指定非绑定窗口的子窗口)
        虚拟键码: 虚拟键码
        窗口状态: 窗口状态，-1/0不设置，其他值为操作前窗口设置(值)参考: HCWIN_SetWindowState的参数值
        
    Returns:
        int: 操作结果
    """
    hd = Config.get_hd()
    func = hd.HCMKB_SendKeyUpF
    func.restype = ctypes.c_int64
    func.argtypes = [ctypes.c_int32, ctypes.c_int32, ctypes.c_int32, ctypes.c_int32]
    
    return func(窗口序号, hwnd, 虚拟键码, 窗口状态)

def HD键鼠_句柄发送按键(窗口序号: int, hwnd: int, 虚拟键码: int, 延时毫秒: int = 20, 窗口状态: int = 0) -> int:
    # INT64 __stdcall HCMKB_SendKeyPressF(INT32 窗口序号, INT32 hwnd, INT32 虚拟键码, INT32 延时毫秒, INT32 窗口状态);
    """
    按下并弹起发送键码到指定窗口（可以不用通讯调用）
    
    Args:
        窗口序号: 窗口序号 (不需要通讯也可以调用,指定一个大于0的序号就行或者任意一个)
        hwnd: hwnd窗口句柄(指定子窗口的窗口句柄,可以指定非绑定窗口的子窗口)
        虚拟键码: 虚拟键码
        延时毫秒: 按下和弹起之间的间隔时间
        窗口状态: 窗口状态，-1/0不设置，其他值为操作前窗口设置(值)参考: HCWIN_SetWindowState的参数值
        
    Returns:
        int: 操作结果
    """
    hd = Config.get_hd()
    func = hd.HCMKB_SendKeyPressF
    func.restype = ctypes.c_int64
    func.argtypes = [ctypes.c_int32, ctypes.c_int32, ctypes.c_int32, ctypes.c_int32, ctypes.c_int32]
    
    return func(窗口序号, hwnd, 虚拟键码, 延时毫秒, 窗口状态)

def HD键鼠_句柄发送清空文本(窗口序号: int, hwnd: int, 窗口状态: int = 0) -> int:
    # INT64 __stdcall HCMKB_SendDeleteTextF(INT32 窗口序号, INT32 hwnd, INT32 窗口状态);
    """
    可以清空子窗口的内容（可以不用通讯调用）
    
    Args:
        窗口序号: 窗口序号 (不需要通讯也可以调用,指定一个大于0的序号就行或者任意一个)
        hwnd: hwnd窗口句柄(指定子窗口的窗口句柄,可以指定非绑定窗口的子窗口) 比如:edit richedit
        窗口状态: 窗口状态，-1/0不设置，其他值为操作前窗口设置(值)参考: HCWIN_SetWindowState的参数值
        
    Returns:
        int: 操作结果
    """
    hd = Config.get_hd()
    func = hd.HCMKB_SendDeleteTextF
    func.restype = ctypes.c_int64
    func.argtypes = [ctypes.c_int32, ctypes.c_int32, ctypes.c_int32]
    
    return func(窗口序号, hwnd, 窗口状态)

def HD键鼠_设置鼠标轨迹参数(步长: int = 30, 步数: int = 100, 每步延迟: int = 20, 开启调试: bool = False) -> int:
    # INT64 __stdcall HCMKB_SetRealMouse(INT32 步长, INT32 步数, INT32 每步延迟, BOOL 开启调试);
    """
    设置鼠标轨迹参数(当移动鼠标开启轨迹生效)
    
    Args:
        步长: 针对直线轨迹有效
        步数: 针对曲线随机轨迹有效
        每步延迟: 中间点每个点发送的频率(毫秒)
        开启调试: 真为开启,只有在调试版本才会触发,会弹窗实时显示轨迹坐标点
        
    Returns:
        int: 操作结果
    """
    hd = Config.get_hd()
    func = hd.HCMKB_SetRealMouse
    func.restype = ctypes.c_int64
    func.argtypes = [ctypes.c_int32, ctypes.c_int32, ctypes.c_int32, ctypes.c_bool]
    
    return func(步长, 步数, 每步延迟, 开启调试)

def HD键鼠_获取鼠标位置(窗口序号: int) -> int:
    # INT64 __stdcall HCMKB_GetMousePos(INT32 窗口序号);
    """
    获取后台/前台鼠标位置
    
    Args:
        窗口序号: 窗口序号 特别说明:1.序号为-1表示全局前台 2.如果后台绑定normal,序号不为-1表示窗口前台
        
    Returns:
        int: 返回值大于等于0:表示XY组成的8字节 低4字节为X 高4字节为Y
    """
    hd = Config.get_hd()
    func = hd.HCMKB_GetMousePos
    func.restype = ctypes.c_int64
    func.argtypes = [ctypes.c_int32]
    
    return func(窗口序号)



from .config import Config, ctypes
from .config import auto_encode

# JSON_HANDLE __stdcall HDJSON_Create();
def HDJSON_Create() -> int:
    """
    创建JSON对象
    
    Returns:
        int: 64位整数句柄，映射一个JSON对象
    """
    hd = Config.get_hd()
    
    HDJSON_Create = hd.HDJSON_Create
    HDJSON_Create.restype = ctypes.c_int64
    HDJSON_Create.argtypes = []
    
    ret = HDJSON_Create()
    return ret

# BOOL __stdcall HDJSON_Parse(JSON_HANDLE hJson, const char* str);
def HDJSON_Parse(JSON句柄: int, JSON字符串: str) -> bool:
    """
    JSON字符串解析（支持中文）
    
    Args:
        JSON句柄: JSON对象句柄
        JSON字符串: JSON字符串
    
    Returns:
        bool: 解析结果（见HD返回值表）
    """
    hd = Config.get_hd()
    
    HDJSON_Parse = hd.HDJSON_Parse
    HDJSON_Parse.restype = ctypes.c_bool
    HDJSON_Parse.argtypes = [ctypes.c_int64, ctypes.c_char_p]
    
    ret = HDJSON_Parse(ctypes.c_int64(JSON句柄), auto_encode(JSON字符串))
    return ret

def HDJSON_Free(hJson: int):
    """
    接口说明:
        释放JSON对象
    函数原型：
        void __stdcall HDJSON_Free(JSON_HANDLE h);
    参数定义:
        hJson: JSON对象句柄
    返回值:
        无
    备注:
        JSON_HANDLE 是一个64位整数句柄,映射一个JSON对象
    """
    hd = Config.get_hd()
    HDJSON_Free = hd.HDJSON_Free
    HDJSON_Free.restype = None
    HDJSON_Free.argtypes = [ctypes.c_int64]
    HDJSON_Free(ctypes.c_int64(hJson))

def HDJSON_GetString(hJson: int, key: str) -> str:
    """
    接口说明:
        通过键从JSON对象中获取字符串值-支持中文
    函数原型：
        const char* __stdcall HDJSON_GetString(JSON_HANDLE hJson, const char* key);
    参数定义:
        hJson: JSON对象句柄
        key: 键名 不支持中文
    返回值:
        str: 字符串值
    备注:
        JSON_HANDLE 是一个64位整数句柄,映射一个JSON对象
    """
    hd = Config.get_hd()
    HDJSON_GetString = hd.HDJSON_GetString
    HDJSON_GetString.restype = ctypes.c_char_p
    HDJSON_GetString.argtypes = [ctypes.c_int64, ctypes.c_char_p]
    key_bytes = auto_encode(key)
    result = HDJSON_GetString(ctypes.c_int64(hJson), key_bytes)
    return result.decode('utf-8') if result else None

def HDJSON_GetInt(hJson: int, key: str) -> int:
    """
    接口说明:
        通过键从JSON对象中获取4字节整数值
    函数原型：
        int __stdcall HDJSON_GetInt(JSON_HANDLE hJson, const char* key);
    参数定义:
        hJson: JSON对象句柄
        key: 键名 不支持中文
    返回值:
        int: 4字节整数值
    备注:
        JSON_HANDLE 是一个64位整数句柄,映射一个JSON对象
    """
    hd = Config.get_hd()
    HDJSON_GetInt = hd.HDJSON_GetInt
    HDJSON_GetInt.restype = ctypes.c_int32
    HDJSON_GetInt.argtypes = [ctypes.c_int64, ctypes.c_char_p]
    key_bytes = auto_encode(key)
    return HDJSON_GetInt(ctypes.c_int64(hJson), key_bytes)

def HDJSON_GetInt64(hJson: int, key: str) -> int:
    """
    接口说明:
        通过键从JSON对象中获取8字节整数值
    函数原型：
        __int64 __stdcall HDJSON_GetInt64(JSON_HANDLE hJson, const char* key);
    参数定义:
        hJson: JSON对象句柄
        key: 键名 不支持中文
    返回值:
        int: 8字节整数值
    备注:
        JSON_HANDLE 是一个64位整数句柄,映射一个JSON对象
    """
    hd = Config.get_hd()
    HDJSON_GetInt64 = hd.HDJSON_GetInt64
    HDJSON_GetInt64.restype = ctypes.c_int64
    HDJSON_GetInt64.argtypes = [ctypes.c_int64, ctypes.c_char_p]
    key_bytes = auto_encode(key)
    return HDJSON_GetInt64(ctypes.c_int64(hJson), key_bytes)

def HDJSON_GetFloat(hJson: int, key: str) -> float:
    """
    接口说明:
        通过键从JSON对象中获取4字节浮点数值
    函数原型：
        float __stdcall HDJSON_GetFloat(JSON_HANDLE hJson, const char* key);
    参数定义:
        hJson: JSON对象句柄
        key: 键名 不支持中文
    返回值:
        float: 4字节浮点数值
    备注:
        JSON_HANDLE 是一个64位整数句柄,映射一个JSON对象
    """
    hd = Config.get_hd()
    HDJSON_GetFloat = hd.HDJSON_GetFloat
    HDJSON_GetFloat.restype = ctypes.c_float
    HDJSON_GetFloat.argtypes = [ctypes.c_int64, ctypes.c_char_p]
    key_bytes = auto_encode(key)
    return HDJSON_GetFloat(ctypes.c_int64(hJson), key_bytes)

def HDJSON_GetDouble(hJson: int, key: str) -> float:
    """
    接口说明:
        通过键从JSON对象中获取8字节浮点数值
    函数原型：
        double __stdcall HDJSON_GetDouble(JSON_HANDLE hJson, const char* key);
    参数定义:
        hJson: JSON对象句柄
        key: 键名 不支持中文
    返回值:
        float: 8字节浮点数值
    备注:
        JSON_HANDLE 是一个64位整数句柄,映射一个JSON对象
    """
    hd = Config.get_hd()
    HDJSON_GetDouble = hd.HDJSON_GetDouble
    HDJSON_GetDouble.restype = ctypes.c_double
    HDJSON_GetDouble.argtypes = [ctypes.c_int64, ctypes.c_char_p]
    key_bytes = auto_encode(key)
    return HDJSON_GetDouble(ctypes.c_int64(hJson), key_bytes)

def HDJSON_GetBool(hJson: int, key: str) -> bool:
    """
    接口说明:
        通过键从JSON对象中获取4字节逻辑型数值
    函数原型：
        BOOL __stdcall HDJSON_GetBool (JSON_HANDLE hJson, const char* key);
    参数定义:
        hJson: JSON对象句柄
        key: 键名 不支持中文
    返回值:
        bool: 4字节逻辑型数值
    备注:
        JSON_HANDLE 是一个64位整数句柄,映射一个JSON对象
    """
    hd = Config.get_hd()
    HDJSON_GetBool = hd.HDJSON_GetBool
    HDJSON_GetBool.restype = ctypes.c_bool
    HDJSON_GetBool.argtypes = [ctypes.c_int64, ctypes.c_char_p]
    key_bytes = auto_encode(key)
    return HDJSON_GetBool(ctypes.c_int64(hJson), key_bytes)

def HDJSON_GetArray(hJson: int, key: str) -> int:
    """
    接口说明:
        通过键从JSON对象中获取JSON数组对象
    函数原型：
        JSON_HANDLE __stdcall HDJSON_GetArray(JSON_HANDLE hJson, const char* key);
    参数定义:
        hJson: JSON对象句柄
        key: 键名 不支持中文
    返回值:
        JSON_HANDLE: 64位整数句柄,映射一个JSON对象
    备注:
        JSON_HANDLE 是一个64位整数句柄,映射一个JSON对象
    """
    hd = Config.get_hd()
    HDJSON_GetArray = hd.HDJSON_GetArray
    HDJSON_GetArray.restype = ctypes.c_int64
    HDJSON_GetArray.argtypes = [ctypes.c_int64, ctypes.c_char_p]
    key_bytes = auto_encode(key)
    return HDJSON_GetArray(ctypes.c_int64(hJson), key_bytes)

def HDJSON_CreateArray() -> int:
    """
    接口说明:
        创建json数组对象
    函数原型：
        JSON_HANDLE __stdcall HDJSON_CreateArray ();
    参数定义:
        无
    返回值:
        JSON_HANDLE: 64位整数句柄,映射一个JSON对象
    备注:
        见HD返回值表
    """
    hd = Config.get_hd()
    HDJSON_CreateArray = hd.HDJSON_CreateArray
    HDJSON_CreateArray.restype = ctypes.c_int64
    HDJSON_CreateArray.argtypes = []
    return HDJSON_CreateArray()

def HDJSON_ArraySize(hArray: int) -> int:
    """
    接口说明:
        获取JSON数组对象的元素大小
    函数原型：
        int __stdcall HDJSON_ArraySize(JSON_HANDLE hArray);
    参数定义:
        hArray: JSON对象句柄
    返回值:
        int: 元素数量
    备注:
        JSON_HANDLE 是一个64位整数句柄,映射一个JSON对象
    """
    hd = Config.get_hd()
    HDJSON_ArraySize = hd.HDJSON_ArraySize
    HDJSON_ArraySize.restype = ctypes.c_int32
    HDJSON_ArraySize.argtypes = [ctypes.c_int64]
    return HDJSON_ArraySize(ctypes.c_int64(hArray))

def HDJSON_ArrayGetInt(hArray: int, index: int) -> int:
    """
    接口说明:
        通过键从JSON数组对象中获取4字节整数值
    函数原型：
        int __stdcall HDJSON_ArrayGetInt (JSON_HANDLE hArray, int index);
    参数定义:
        hArray: JSON对象句柄
        index: 元素索引 从0开始
    返回值:
        int: 4字节整数值
    备注:
        JSON_HANDLE 是一个64位整数句柄,映射一个JSON对象
    """
    hd = Config.get_hd()
    HDJSON_ArrayGetInt = hd.HDJSON_ArrayGetInt
    HDJSON_ArrayGetInt.restype = ctypes.c_int32
    HDJSON_ArrayGetInt.argtypes = [ctypes.c_int64, ctypes.c_int32]
    return HDJSON_ArrayGetInt(ctypes.c_int64(hArray), ctypes.c_int32(index))

def HDJSON_ArrayGetInt64(hArray: int, index: int) -> int:
    """
    接口说明:
        通过键从JSON数组对象中获取8字节整数值
    函数原型：
        __int64 __stdcall HDJSON_ArrayGetInt64(JSON_HANDLE hArray, int index);
    参数定义:
        hArray: JSON对象句柄
        index: 元素索引 从0开始
    返回值:
        int: 8字节整数值
    备注:
        JSON_HANDLE 是一个64位整数句柄,映射一个JSON对象
    """
    hd = Config.get_hd()
    HDJSON_ArrayGetInt64 = hd.HDJSON_ArrayGetInt64
    HDJSON_ArrayGetInt64.restype = ctypes.c_int64
    HDJSON_ArrayGetInt64.argtypes = [ctypes.c_int64, ctypes.c_int32]
    return HDJSON_ArrayGetInt64(ctypes.c_int64(hArray), ctypes.c_int32(index))

def HDJSON_ArrayGetString(hArray: int, index: int) -> str:
    """
    接口说明:
        通过键从JSON数组对象中获取字符串值 -支持中文
    函数原型：
        const char* __stdcall HDJSON_ArrayGetString(JSON_HANDLE hArray, int index);
    参数定义:
        hArray: JSON对象句柄
        index: 元素索引 从0开始
    返回值:
        str: 字符串值
    备注:
        JSON_HANDLE 是一个64位整数句柄,映射一个JSON对象
    """
    hd = Config.get_hd()
    HDJSON_ArrayGetString = hd.HDJSON_ArrayGetString
    HDJSON_ArrayGetString.restype = ctypes.c_char_p
    HDJSON_ArrayGetString.argtypes = [ctypes.c_int64, ctypes.c_int32]
    result = HDJSON_ArrayGetString(ctypes.c_int64(hArray), ctypes.c_int32(index))
    return result.decode('utf-8') if result else None

def HDJSON_ArrayGetFloat(hArray: int, index: int) -> float:
    """
    接口说明:
        通过键从JSON数组对象中获取4字节浮点数值
    函数原型：
        float __stdcall HDJSON_ArrayGetFloat(JSON_HANDLE hArray, int index);
    参数定义:
        hArray: JSON对象句柄
        index: 元素索引 从0开始
    返回值:
        float: 4字节浮点数
    备注:
        JSON_HANDLE 是一个64位整数句柄,映射一个JSON对象
    """
    hd = Config.get_hd()
    HDJSON_ArrayGetFloat = hd.HDJSON_ArrayGetFloat
    HDJSON_ArrayGetFloat.restype = ctypes.c_float
    HDJSON_ArrayGetFloat.argtypes = [ctypes.c_int64, ctypes.c_int32]
    return HDJSON_ArrayGetFloat(ctypes.c_int64(hArray), ctypes.c_int32(index))

def HDJSON_ArrayGetDouble(hArray: int, index: int) -> float:
    """
    接口说明:
        通过键从JSON数组对象中获取8节浮点数值
    函数原型：
        double __stdcall HDJSON_ArrayGetDouble(JSON_HANDLE hArray, int index);
    参数定义:
        hArray: JSON对象句柄
        index: 元素索引 从0开始
    返回值:
        float: 8字节浮点数
    备注:
        JSON_HANDLE 是一个64位整数句柄,映射一个JSON对象
    """
    hd = Config.get_hd()
    HDJSON_ArrayGetDouble = hd.HDJSON_ArrayGetDouble
    HDJSON_ArrayGetDouble.restype = ctypes.c_double
    HDJSON_ArrayGetDouble.argtypes = [ctypes.c_int64, ctypes.c_int32]
    return HDJSON_ArrayGetDouble(ctypes.c_int64(hArray), ctypes.c_int32(index))

def HDJSON_ArrayGetBool(hArray: int, index: int) -> bool:
    """
    接口说明:
        通过键从JSON数组对象中获取逻辑性值
    函数原型：
        BOOL __stdcall HDJSON_ArrayGetBool(JSON_HANDLE hArray, int index);
    参数定义:
        hArray: JSON对象句柄
        index: 元素索引 从0开始
    返回值:
        bool: 4字节逻辑型
    备注:
        JSON_HANDLE 是一个64位整数句柄,映射一个JSON对象
    """
    hd = Config.get_hd()
    HDJSON_ArrayGetBool = hd.HDJSON_ArrayGetBool
    HDJSON_ArrayGetBool.restype = ctypes.c_bool
    HDJSON_ArrayGetBool.argtypes = [ctypes.c_int64, ctypes.c_int32]
    return HDJSON_ArrayGetBool(ctypes.c_int64(hArray), ctypes.c_int32(index))

def HDJSON_ArrayGetObject(hArray: int, index: int) -> int:
    """
    接口说明:
        通过键从JSON数组对象中获取json对象
    函数原型：
        JSON_HANDLE __stdcall HDJSON_ArrayGetObject(JSON_HANDLE hArray, int index);
    参数定义:
        hArray: JSON对象句柄
        index: 元素索引 从0开始
    返回值:
        JSON_HANDLE: 64位整数句柄,映射一个JSON对象
    备注:
        JSON_HANDLE 是一个64位整数句柄,映射一个JSON对象
    """
    hd = Config.get_hd()
    HDJSON_ArrayGetObject = hd.HDJSON_ArrayGetObject
    HDJSON_ArrayGetObject.restype = ctypes.c_int64
    HDJSON_ArrayGetObject.argtypes = [ctypes.c_int64, ctypes.c_int32]
    return HDJSON_ArrayGetObject(ctypes.c_int64(hArray), ctypes.c_int32(index))

def HDJSON_SetString(hJson: int, key: str, value: str) -> bool:
    """
    接口说明:
        向JSON对象中插入一个字符串类型的键值对-支持中文
    函数原型：
        BOOL __stdcall HDJSON_SetString(JSON_HANDLE hJson, const char* key, const char* value);
    参数定义:
        hJson: JSON对象句柄
        key: 键名 不支持中文
        value: 字符串 ascii编码 支持中文
    返回值:
        bool: 见HD返回值表
    备注:
        JSON_HANDLE 是一个64位整数句柄,映射一个JSON对象
    """
    hd = Config.get_hd()
    HDJSON_SetString = hd.HDJSON_SetString
    HDJSON_SetString.restype = ctypes.c_bool
    HDJSON_SetString.argtypes = [ctypes.c_int64, ctypes.c_char_p, ctypes.c_char_p]
    key_bytes = auto_encode(key)
    value_bytes = auto_encode(value)
    return HDJSON_SetString(ctypes.c_int64(hJson), key_bytes, value_bytes)

def HDJSON_SetInt(hJson: int, key: str, value: int) -> bool:
    """
    接口说明:
        向JSON对象中插入一个4字节整数类型的键值对
    函数原型：
        BOOL __stdcall HDJSON_SetInt(JSON_HANDLE hJson, const char* key, int value);
    参数定义:
        hJson: JSON对象句柄
        key: 键名 不支持中文
        value: 4字节整数值
    返回值:
        bool: 见HD返回值表
    备注:
        JSON_HANDLE 是一个64位整数句柄,映射一个JSON对象
    """
    hd = Config.get_hd()
    HDJSON_SetInt = hd.HDJSON_SetInt
    HDJSON_SetInt.restype = ctypes.c_bool
    HDJSON_SetInt.argtypes = [ctypes.c_int64, ctypes.c_char_p, ctypes.c_int32]
    key_bytes = auto_encode(key)
    return HDJSON_SetInt(ctypes.c_int64(hJson), key_bytes, ctypes.c_int32(value))

def HDJSON_SetInt64(hJson: int, key: str, value: int) -> bool:
    """
    接口说明:
        向JSON对象中插入一个8字节整数类型的键值对
    函数原型：
        BOOL __stdcall HDJSON_SetInt64(JSON_HANDLE hJson, const char* key, __int64 value);
    参数定义:
        hJson: JSON对象句柄
        key: 键名 不支持中文
        value: 8字节整数值
    返回值:
        bool: 见HD返回值表
    备注:
        JSON_HANDLE 是一个64位整数句柄,映射一个JSON对象
    """
    hd = Config.get_hd()
    HDJSON_SetInt64 = hd.HDJSON_SetInt64
    HDJSON_SetInt64.restype = ctypes.c_bool
    HDJSON_SetInt64.argtypes = [ctypes.c_int64, ctypes.c_char_p, ctypes.c_int64]
    key_bytes = auto_encode(key)
    return HDJSON_SetInt64(ctypes.c_int64(hJson), key_bytes, ctypes.c_int64(value))

def HDJSON_SetDouble(hJson: int, key: str, value: float) -> bool:
    """
    接口说明:
        向JSON对象中插入一个8字节浮点数类型的键值对
    函数原型：
        BOOL __stdcall HDJSON_SetDouble(JSON_HANDLE hJson, const char* key, double value);
    参数定义:
        hJson: JSON对象句柄
        key: 键名 不支持中文
        value: 8字节浮点数值
    返回值:
        bool: 见HD返回值表
    备注:
        JSON_HANDLE 是一个64位整数句柄,映射一个JSON对象
    """
    hd = Config.get_hd()
    HDJSON_SetDouble = hd.HDJSON_SetDouble
    HDJSON_SetDouble.restype = ctypes.c_bool
    HDJSON_SetDouble.argtypes = [ctypes.c_int64, ctypes.c_char_p, ctypes.c_double]
    key_bytes = auto_encode(key)
    return HDJSON_SetDouble(ctypes.c_int64(hJson), key_bytes, ctypes.c_double(value))

def HDJSON_SetBool(hJson: int, key: str, value: bool) -> bool:
    """
    接口说明:
        向JSON对象中插入一个4字节逻辑型类型的键值对
    函数原型：
        BOOL __stdcall HDJSON_SetBool(JSON_HANDLE hJson, const char* key, BOOL value);
    参数定义:
        hJson: JSON对象句柄
        key: 键名 不支持中文
        value: 4字节逻辑型值
    返回值:
        bool: 见HD返回值表
    备注:
        JSON_HANDLE 是一个64位整数句柄,映射一个JSON对象
    """
    hd = Config.get_hd()
    HDJSON_SetBool = hd.HDJSON_SetBool
    HDJSON_SetBool.restype = ctypes.c_bool
    HDJSON_SetBool.argtypes = [ctypes.c_int64, ctypes.c_char_p, ctypes.c_bool]
    key_bytes = auto_encode(key)
    return HDJSON_SetBool(ctypes.c_int64(hJson), key_bytes, ctypes.c_bool(value))

def HDJSON_SetArray(hJson: int, key: str, hArray: int) -> bool:
    """
    接口说明:
        向JSON对象中插入一个json数组对象类型的键值对
    函数原型：
        BOOL __stdcall HDJSON_SetArray(JSON_HANDLE hJson, const char* key, JSON_HANDLE hArray);
    参数定义:
        hJson: JSON对象句柄
        key: 键名 不支持中文
        hArray: json数组对象句柄
    返回值:
        bool: 见HD返回值表
    备注:
        JSON_HANDLE 是一个64位整数句柄,映射一个JSON对象
    """
    hd = Config.get_hd()
    HDJSON_SetArray = hd.HDJSON_SetArray
    HDJSON_SetArray.restype = ctypes.c_bool
    HDJSON_SetArray.argtypes = [ctypes.c_int64, ctypes.c_char_p, ctypes.c_int64]
    key_bytes = auto_encode(key)
    return HDJSON_SetArray(ctypes.c_int64(hJson), key_bytes, ctypes.c_int64(hArray))

def HDJSON_ArrayAddString(hArray: int, value: str) -> bool:
    """
    接口说明:
        向JSON数组对象中插入一个字符串的元素
    函数原型：
        BOOL __stdcall HDJSON_ArrayAddString(JSON_HANDLE hArray, const char* value);
    参数定义:
        hArray: JSON对象句柄
        value: 字符串元素 支持中文
    返回值:
        bool: 见HD返回值表
    备注:
        JSON_HANDLE 是一个64位整数句柄,映射一个JSON对象
    """
    hd = Config.get_hd()
    HDJSON_ArrayAddString = hd.HDJSON_ArrayAddString
    HDJSON_ArrayAddString.restype = ctypes.c_bool
    HDJSON_ArrayAddString.argtypes = [ctypes.c_int64, ctypes.c_char_p]
    value_bytes = auto_encode(value)
    return HDJSON_ArrayAddString(ctypes.c_int64(hArray), value_bytes)

def HDJSON_ArrayAddInt(hArray: int, value: int) -> bool:
    """
    接口说明:
        向JSON数组对象中插入一个4字节整数的元素
    函数原型：
        BOOL __stdcall HDJSON_ArrayAddInt(JSON_HANDLE hArray, int value);
    参数定义:
        hArray: JSON对象句柄
        value: 4字节整数值
    返回值:
        bool: 见HD返回值表
    备注:
        JSON_HANDLE 是一个64位整数句柄,映射一个JSON对象
    """
    hd = Config.get_hd()
    HDJSON_ArrayAddInt = hd.HDJSON_ArrayAddInt
    HDJSON_ArrayAddInt.restype = ctypes.c_bool
    HDJSON_ArrayAddInt.argtypes = [ctypes.c_int64, ctypes.c_int32]
    return HDJSON_ArrayAddInt(ctypes.c_int64(hArray), ctypes.c_int32(value))

def HDJSON_ArrayAddDouble(hArray: int, value: float) -> bool:
    """
    接口说明:
        向JSON数组对象中插入一个8字节浮点数的元素
    函数原型：
        BOOL __stdcall HDJSON_ArrayAddDouble(JSON_HANDLE hArray, double value);
    参数定义:
        hArray: JSON对象句柄
        value: 8字节浮点数
    返回值:
        bool: 见HD返回值表
    备注:
        JSON_HANDLE 是一个64位整数句柄,映射一个JSON对象
    """
    hd = Config.get_hd()
    HDJSON_ArrayAddDouble = hd.HDJSON_ArrayAddDouble
    HDJSON_ArrayAddDouble.restype = ctypes.c_bool
    HDJSON_ArrayAddDouble.argtypes = [ctypes.c_int64, ctypes.c_double]
    return HDJSON_ArrayAddDouble(ctypes.c_int64(hArray), ctypes.c_double(value))

def HDJSON_ArrayAddFloat(hArray: int, value: float) -> bool:
    """
    接口说明:
        向JSON数组对象中插入一个4字节浮点数的元素
    函数原型：
        BOOL __stdcall HDJSON_ArrayAddFloat(JSON_HANDLE hArray, float value);
    参数定义 :
        hArray: JSON对象句柄
        value: 4字节浮点数
    返回值:
        bool: 见HD返回值表
    备注:
        JSON_HANDLE 是一个64位整数句柄,映射一个JSON对象
    """
    hd = Config.get_hd()
    HDJSON_ArrayAddFloat = hd.HDJSON_ArrayAddFloat
    HDJSON_ArrayAddFloat.restype = ctypes.c_bool
    HDJSON_ArrayAddFloat.argtypes = [ctypes.c_int64, ctypes.c_float]
    return HDJSON_ArrayAddFloat(ctypes.c_int64(hArray), ctypes.c_float(value))

def HDJSON_ArrayAddInt64(hArray: int, value: int) -> bool:
    """
    接口说明:
        向JSON数组对象中插入一个8字节整数的元素
    函数原型：
        BOOL __stdcall HDJSON_ArrayAddInt64(JSON_HANDLE hArray, __int64 value);
    参数定义 :
        hArray: JSON对象句柄
        value: 8字节整数
    返回值:
        bool: 见HD返回值表
    备注:
        JSON_HANDLE 是一个64位整数句柄,映射一个JSON对象
    """
    hd = Config.get_hd()
    HDJSON_ArrayAddInt64 = hd.HDJSON_ArrayAddInt64
    HDJSON_ArrayAddInt64.restype = ctypes.c_bool
    HDJSON_ArrayAddInt64.argtypes = [ctypes.c_int64, ctypes.c_int64]
    return HDJSON_ArrayAddInt64(ctypes.c_int64(hArray), ctypes.c_int64(value))

def HDJSON_ArrayAddBool(hArray: int, value: bool) -> bool:
    """
    接口说明:
        向JSON数组对象中插入一个4字节逻辑型的元素
    函数原型：
        BOOL __stdcall HDJSON_ArrayAddBool(JSON_HANDLE hArray, BOOL value);
    参数定义 :
        hArray: JSON对象句柄
        value: 4字节逻辑型
    返回值:
        bool: 见HD返回值表
    备注:
        JSON_HANDLE 是一个64位整数句柄,映射一个JSON对象
    """
    hd = Config.get_hd()
    HDJSON_ArrayAddBool = hd.HDJSON_ArrayAddBool
    HDJSON_ArrayAddBool.restype = ctypes.c_bool
    HDJSON_ArrayAddBool.argtypes = [ctypes.c_int64, ctypes.c_bool]
    return HDJSON_ArrayAddBool(ctypes.c_int64(hArray), ctypes.c_bool(value))

def HDJSON_ToString(hJson: int) -> str:
    """
    接口说明:
        通过JSON对象返回字符串形式的JSON字符串
    函数原型：
        const char* __stdcall HDJSON_ToString(JSON_HANDLE hJson);
    参数定义 :
        hJson: JSON对象句柄
    返回值:
        str: JSON字符串
    备注:
        JSON_HANDLE 是一个64位整数句柄,映射一个JSON对象
    """
    hd = Config.get_hd()
    HDJSON_ToString = hd.HDJSON_ToString
    HDJSON_ToString.restype = ctypes.c_char_p
    HDJSON_ToString.argtypes = [ctypes.c_int64]
    result = HDJSON_ToString(ctypes.c_int64(hJson))
    return result.decode('utf-8') if result else None

def HDJSON_GetLastError() -> str:
    """
    接口说明:
        获取当前线程最近调用json接口的错误返回值
    函数原型：
        const char* __stdcall HDJSON_GetLastError();
    参数定义 :
        无
    返回值:
        str: 错误字符串
    备注:
        JSON_HANDLE 是一个64位整数句柄,映射一个JSON对象
    """
    hd = Config.get_hd()
    HDJSON_GetLastError = hd.HDJSON_GetLastError
    HDJSON_GetLastError.restype = ctypes.c_char_p
    HDJSON_GetLastError.argtypes = []
    result = HDJSON_GetLastError()
    return result.decode('utf-8') if result else None


from .config import Config, ctypes
from .config import auto_encode

def HD_Path(dll路径: str) -> None:
    """
    加载DLL文件
    
    Args:
        dll路径: DLL文件所在路径，例如 "./lib/HDDebug.dll"
    """
    Config.load_dll(dll路径)

# INT64 __stdcall HCHD_Login(char* account, char* password, char* appName, char* appLparam, BOOL bAutoUpdate, BOOL bShowMsgBox);
def HD登录_登录(账号: str, 密码: str, 应用名称: str, 应用参数: str, 是否自动更新: bool, 是否显示消息框: bool) -> int:
    """
    HD登录验证接口
    
    Args:
        账号: 登录账号
        密码: 登录密码
        应用名称: 中控进程名字，指定了方便自动更新
        应用参数: 打开中控的启动参数，指定了方便自动更新
        是否自动更新: 是否自动更新
        是否显示消息框: 如果需要更新是否弹出消息框提醒
    
    Returns:
        int: 版本号
    """
    hd = Config.get_hd()
    
    HCHD_Login = hd.HCHD_Login
    HCHD_Login.restype = ctypes.c_int64
    HCHD_Login.argtypes = [
        ctypes.c_char_p,
        ctypes.c_char_p,
        ctypes.c_char_p,
        ctypes.c_char_p,
        ctypes.c_bool,
        ctypes.c_bool
    ]
    
    ret = HCHD_Login(
        auto_encode(账号),
        auto_encode(密码),
        auto_encode(应用名称),
        auto_encode(应用参数),
        ctypes.c_bool(是否自动更新),
        ctypes.c_bool(是否显示消息框)
    )
    return ret

# INT64 __stdcall HCHD_GetLastLoginFYI();
def HD登录_获取最近登录点数() -> int:
    """
    获取最近登录时候的点数
    
    Returns:
        int: 最近登录点数
    """
    hd = Config.get_hd()
    
    HCHD_GetLastLoginFYI = hd.HCHD_GetLastLoginFYI
    HCHD_GetLastLoginFYI.restype = ctypes.c_int64
    HCHD_GetLastLoginFYI.argtypes = []
    
    ret = HCHD_GetLastLoginFYI()
    return ret

# INT64 __stdcall HCHD_GetExpiredTimeStamp();
def HD登录_获取最近登录时间() -> int:
    """
    获取最近登录时间戳
    
    Returns:
        int: 最近登录时间戳
    """
    hd = Config.get_hd()
    
    HCHD_GetExpiredTimeStamp = hd.HCHD_GetExpiredTimeStamp
    HCHD_GetExpiredTimeStamp.restype = ctypes.c_int64
    HCHD_GetExpiredTimeStamp.argtypes = []
    
    ret = HCHD_GetExpiredTimeStamp()
    return ret

# INT64 __stdcall HCHD_GetFYI();
def HD登录_获取点数() -> int:
    """
    获取当前点数
    
    Returns:
        int: 当前点数
    """
    hd = Config.get_hd()
    
    HCHD_GetFYI = hd.HCHD_GetFYI
    HCHD_GetFYI.restype = ctypes.c_int64
    HCHD_GetFYI.argtypes = []
    
    ret = HCHD_GetFYI()
    return ret

# INT64 __stdcall HCHD_GetOpenMaxNum();
def HD登录_获取最大多开数() -> int:
    """
    获取当前最大打开窗口数
    
    Returns:
        int: 最大多开数
    """
    hd = Config.get_hd()
    
    HCHD_GetOpenMaxNum = hd.HCHD_GetOpenMaxNum
    HCHD_GetOpenMaxNum.restype = ctypes.c_int64
    HCHD_GetOpenMaxNum.argtypes = []
    
    ret = HCHD_GetOpenMaxNum()
    return ret

# INT64 __stdcall HCHD_GetVersion();
def HD登录_获取版本号() -> int:
    """
    获取当前插件版本号
    
    Returns:
        int: 版本号
    """
    hd = Config.get_hd()
    
    HCHD_GetVersion = hd.HCHD_GetVersion
    HCHD_GetVersion.restype = ctypes.c_int64
    HCHD_GetVersion.argtypes = []
    
    ret = HCHD_GetVersion()
    return ret


from .config import Config, ctypes
from .config import auto_encode

# INT64 __stdcall HCSD_SetColor(int lineColor, int textColor, int backColor);
def HD调试_设置颜色(线颜色: int = 0x0000FF00, 文本颜色: int = 0x00FFFF00, 背景颜色: int = 0x00000000) -> int:
    """
    设置全局可视化标注颜色值（用于调试）
    
    Args:
        线颜色: 线条颜色，默认0x0000FF00
        文本颜色: 文本颜色，默认0x00FFFF00
        背景颜色: 背景颜色，默认0x00000000
    
    Returns:
        int: 返回值代码
    """
    hd = Config.get_hd()
    
    HCSD_SetColor = hd.HCSD_SetColor
    HCSD_SetColor.restype = ctypes.c_int64
    HCSD_SetColor.argtypes = [
        ctypes.c_int32,
        ctypes.c_int32,
        ctypes.c_int32
    ]
    
    ret = HCSD_SetColor(
        ctypes.c_int32(线颜色),
        ctypes.c_int32(文本颜色),
        ctypes.c_int32(背景颜色)
    )
    return ret

# INT64 __stdcall HCSD_SetFollowClassTitleName(int pid, int hwnd, char* className, char* titleName);
def HD调试_设置调试窗口跟随(进程PID: int = None, 窗口句柄: int = None, 类名: str = None, 标题名: str = None) -> int:
    """
    设置当前调试窗口跟随的进程信息（用于调试）
    
    Args:
        进程PID: 指定pid，内部会配合类名或标题名找绑定的窗口句柄
        窗口句柄: 指定了窗口句柄，其他3个参数无效
        类名: 窗口类名，可以为None
        标题名: 窗口标题名，可以为None
    
    Returns:
        int: 返回值代码
    """
    hd = Config.get_hd()
    
    HCSD_SetFollowClassTitleName = hd.HCSD_SetFollowClassTitleName
    HCSD_SetFollowClassTitleName.restype = ctypes.c_int64
    HCSD_SetFollowClassTitleName.argtypes = [
        ctypes.c_int32,
        ctypes.c_int32,
        ctypes.c_char_p,
        ctypes.c_char_p
    ]
    
    className_bytes = auto_encode(类名) if 类名 else None
    titleName_bytes = auto_encode(标题名) if 标题名 else None
    
    ret = HCSD_SetFollowClassTitleName(
        ctypes.c_int32(进程PID) if 进程PID else 0,
        ctypes.c_int32(窗口句柄) if 窗口句柄 else 0,
        className_bytes,
        titleName_bytes
    )
    return ret

# INT64 __stdcall HCSD_DrawWinodws(INT64 hwnd, int LineRgbColor, int lineSize, int type, int fillRgbColor);
def HD调试_标记窗口(窗口句柄: int, 线条RGB颜色: int, 线条大小: int, 类型: int = 0, 填充RGB颜色: int = 0) -> int:
    """
    给指定窗口画边框或者填充矩形
    
    Args:
        窗口句柄: 窗口句柄
        线条RGB颜色: 线条颜色
        线条大小: 线条大小
        类型: 0边框，1填充
        填充RGB颜色: 填充色RGB，type=1才有效
    
    Returns:
        int: 返回值代码
    """
    hd = Config.get_hd()
    
    HCSD_DrawWinodws = hd.HCSD_DrawWinodws
    HCSD_DrawWinodws.restype = ctypes.c_int64
    HCSD_DrawWinodws.argtypes = [
        ctypes.c_int64,
        ctypes.c_int32,
        ctypes.c_int32,
        ctypes.c_int32,
        ctypes.c_int32
    ]
    
    ret = HCSD_DrawWinodws(
        ctypes.c_int64(窗口句柄),
        ctypes.c_int32(线条RGB颜色),
        ctypes.c_int32(线条大小),
        ctypes.c_int32(类型),
        ctypes.c_int32(填充RGB颜色)
    )
    return ret

# INT64 __stdcall HCHD_CatchException(BOOL bOpen);
def HD调试_捕捉异常调用堆栈(是否开启: bool = True) -> int:
    """
    开启/关闭捕捉异常调用堆栈
    
    Args:
        是否开启: 是否打开异常捕捉
    
    Returns:
        int: 返回值代码
    """
    hd = Config.get_hd()
    
    HCHD_CatchException = hd.HCHD_CatchException
    HCHD_CatchException.restype = ctypes.c_int64
    HCHD_CatchException.argtypes = [
        ctypes.c_bool
    ]
    
    ret = HCHD_CatchException(ctypes.c_bool(是否开启))
    return ret

# INT64 __stdcall HCSD_SetAttachConsole(BOOL bOpen);
def HD调试_附加控制台(是否开启: bool = True) -> int:
    """
    开启/关闭附加控制台
    
    Args:
        是否开启: 是否打开控制台附加
    
    Returns:
        int: 返回值代码
    """
    hd = Config.get_hd()
    
    HCSD_SetAttachConsole = hd.HCSD_SetAttachConsole
    HCSD_SetAttachConsole.restype = ctypes.c_int64
    HCSD_SetAttachConsole.argtypes = [
        ctypes.c_bool
    ]
    
    ret = HCSD_SetAttachConsole(ctypes.c_bool(是否开启))
    return ret